#
# spec file for package python-requests-cache
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-requests-cache
Version:        1.0.1
Release:        1.3
Summary:        Persistent cache for requests library
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/requests-cache/requests-cache
Source:         https://github.com/requests-cache/requests-cache/archive/refs/tags/v%{version}.tar.gz#/requests-cache-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  psmisc
BuildRequires:  python-rpm-macros
Requires:       python-itsdangerous
Requires:       python-requests >= 2.0.0
Requires:       python-url-normalize >= 1.4
Recommends:     python-redis
Suggests:       python-boto3
Suggests:       python-mongodb
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cattrs}
BuildRequires:  %{python_module gunicorn}
BuildRequires:  %{python_module httpbin}
BuildRequires:  %{python_module itsdangerous}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module pymongo}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis}
BuildRequires:  %{python_module requests >= 2.0.0}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module rich}
BuildRequires:  %{python_module tenacity}
BuildRequires:  %{python_module timeout-decorator}
BuildRequires:  %{python_module url-normalize >= 1.4}
BuildRequires:  redis
# /SECTION
%python_subpackages

%description
Requests-cache is a transparent persistent cache for requests_ library.

It can be useful when you are creating some simple data scraper with constantly
changing parsing logic or data format, and don't want to redownload pages or
write complex error handling and persistence.

Requests-cache ignores all cache headers, it just caches the data for the
time you specify.

If you need library which knows how to use HTTP headers and status codes,
take a look at `CacheControl <https://github.com/ionrock/cachecontrol>`_.

%prep
%setup -q -n requests-cache-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
gunicorn -b 127.0.0.1:8080 httpbin:app -k gevent &
%{_sbindir}/redis-server &
export HTTPBIN_URL=http://localhost:8080/
%pytest -k 'not (dynamodb or gridfs or mongodb)'
killall -w redis-server

%files %{python_files}
%license LICENSE
%doc README.md HISTORY.md docs/*.rst
%{python_sitelib}/requests_cache
%{python_sitelib}/requests_cache-%{version}*-info

%changelog
* Thu May  4 2023 Matej Cepl <mcepl@suse.com>
- WORK IN PROGRESS, TESTS DON’T PASS!
- Update to 1.0.1: (CONGRATULATIONS!)
  - Ignore Cache-Control: must-revalidate and no-cache when
    `cache_control=False`
  - Lots of miscellaneous performance improvements
  - Fast automatic cache cleanup with TTL integration for
    MongoDB, DynamoDB and Redis
  - Improved NoSQL/document database support: human-readable and
    indexable response data in MongoDB and DynamoDB
  - Complete support for Cache-Control headers (including its
    extensions)
  - Complete type hinting and more details from cached responses
  - Redact common authentication headers and parameters from the
    cache by default
  - Improved session settings interface, and more settings for
    refreshing, revalidation, and offline cache usage
- Remaining list of changes all the way to 0.6.3 is too long,
  HISTORY.md is packaged.
* Sat Apr 24 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.3
  * Fix false positive warning with `include_get_headers`
  * Fix handling of `decode_content` parameter for
    `CachedResponse.raw.read()`
  * Replace deprecated pymongo `Collection.count()` with
    `estimated_document_count()`
* Wed Apr 14 2021 John Vandenberg <jayvdb@gmail.com>
- Fix runtime Requires, adding missing prefix python-
- Add Recommends python-redis and Suggests for python-boto3 and
  python-mongodb
- Activate integration tests, including redis
- Update to v0.6.2
  * Explicitly include docs, tests, and examples in sdist
- from v0.6.1
  * Handle errors due to invalid responses in BaseCache.urls
  * Add recently renamed BaseCache.remove_old_entries() back, as an
    alias with a DeprecationWarning
  * Make parent dirs for new SQLite databases
  * Add aws_access_key_id and aws_secret_access_key kwargs to
    DynamoDbDict
  * Update GridFSPickleDict.__delitem__ to raise a KeyError for
    missing items
  * Demote most logging.info statements to debug level
  * Exclude test directory from find_packages()
  * Make integration tests easier to run and/or fail more quickly in
    environments where Docker isn't available
* Sat Apr 10 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.0
  * See https://github.com/reclosedev/requests-cache/blob/master/HISTORY.md
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.2:
  * Fix DeprecationWarning from collections #140
* Tue May  7 2019 pgajdos@suse.com
- version update to 0.5.0
  * Add gridfs support, thanks to @chengguangnan
  * Add dynamodb support, thanks to @ar90n
  * Add response filter #104, thanks to @christopher-dG
  * Fix bulk_commit #78
  * Fix remove_expired_responses missed in __init__.py #93
  * Fix deprecation warnings #122, thanks to mbarkhau
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Mar 28 2017 alarrosa@suse.com
- Initial release
